<?php
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Methods: POST, GET, PUT, DELETE");
header("Content-Type: application/json");

include 'db_connect.php';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Décoder les données JSON envoyées dans le corps de la requête
    $input = json_decode(file_get_contents("php://input"), true);
    
    if ($input) {
        $id = $input['id'];
        $name = $input['name'];
        $code = $input['code'];
        $solution = $input['solution'];

        // Vérifier si l'ID existe déjà
        $checkStmt = $conn->prepare("SELECT id FROM donnees_maroc WHERE id = ?");
        $checkStmt->bind_param("s", $id); // Utilisez "s" pour une chaîne
        $checkStmt->execute();
        $checkStmt->store_result();

        if ($checkStmt->num_rows > 0) {
            echo json_encode(["error" => "Erreur: L'ID existe déjà"]);
        } else {
            // Insérer les données
            $stmt = $conn->prepare("INSERT INTO donnees_maroc (id, name, code, solution) VALUES (?, ?, ?, ?)");
            $stmt->bind_param("ssss", $id, $name, $code, $solution);  // Traitez l'ID comme une chaîne de caractères

            if ($stmt->execute()) {
                echo json_encode(["message" => "Données enregistrées avec succès"]);
            } else {
                echo json_encode(["error" => "Erreur: " . $stmt->error]);
            }
            $stmt->close();
        }
        $checkStmt->close();
    } else {
        echo json_encode(["error" => "Aucune donnée envoyée"]);
    }
} elseif ($_SERVER['REQUEST_METHOD'] === 'GET') {
    if (isset($_GET['id'])) {
        // Lire des données spécifiques par ID
        $id = $_GET['id'];
        $stmt = $conn->prepare("SELECT name, code, solution FROM donnees_maroc WHERE id = ?");
        $stmt->bind_param("s", $id);  // Utilisez "s" pour une chaîne
        $stmt->execute();
        $result = $stmt->get_result();
        $donnee = $result->fetch_assoc();

        if ($donnee) {
            echo json_encode($donnee);
        } else {
            echo json_encode(["error" => "Aucune donnée trouvée pour l'ID $id"]);
        }
        $stmt->close();
    } else {
        // Lire toutes les données si aucun ID n'est spécifié
        $result = $conn->query("SELECT * FROM donnees_maroc");
        $donnees = $result->fetch_all(MYSQLI_ASSOC);
        echo json_encode($donnees);
    }
} elseif ($_SERVER['REQUEST_METHOD'] === 'PUT') {
    // Mettre à jour des données (Update)
    $input = json_decode(file_get_contents("php://input"), true);
    if ($input) {
        $id = $input['id'];
        $name = $input['name'];
        $code = $input['code'];
        $solution = $input['solution'];

        // Vérifier si l'ID existe avant de procéder à la mise à jour
        $checkStmt = $conn->prepare("SELECT id FROM donnees_maroc WHERE id = ?");
        $checkStmt->bind_param("s", $id);  // Utilisez "s" pour une chaîne
        $checkStmt->execute();
        $checkStmt->store_result();

        if ($checkStmt->num_rows === 0) {
            // Si l'ID n'existe pas
            echo json_encode(["error" => "Erreur: L'ID n'existe pas"]);
        } else {
            // Si l'ID existe, effectuer la mise à jour
            $stmt = $conn->prepare("UPDATE donnees_maroc SET name=?, code=?, solution=? WHERE id=?");
            $stmt->bind_param("ssss", $name, $code, $solution, $id);  // Traitez l'ID comme une chaîne

            if ($stmt->execute()) {
                echo json_encode(["message" => "Données mises à jour avec succès"]);
            } else {
                echo json_encode(["error" => "Erreur: " . $stmt->error]);
            }
            $stmt->close();
        }
        $checkStmt->close();
    } else {
        echo json_encode(["error" => "Aucune donnée à mettre à jour"]);
    }
} elseif ($_SERVER['REQUEST_METHOD'] === 'DELETE') {
    // Supprimer des données (Delete)
    $input = json_decode(file_get_contents("php://input"), true);
    if ($input) {
        $id = $input['id'];

        // Vérifier si l'ID existe avant de procéder à la suppression
        $checkStmt = $conn->prepare("SELECT id FROM donnees_maroc WHERE id = ?");
        $checkStmt->bind_param("s", $id);  // Utilisez "s" pour une chaîne
        $checkStmt->execute();
        $checkStmt->store_result();

        if ($checkStmt->num_rows === 0) {
            // Si l'ID n'existe pas, renvoyer un message d'erreur
            echo json_encode(["error" => "Erreur: Aucune donnée trouvée à supprimer pour l'ID $id"]);
        } else {
            // Si l'ID existe, effectuer la suppression
            $stmt = $conn->prepare("DELETE FROM donnees_maroc WHERE id=?");
            $stmt->bind_param("s", $id);  // Traitez l'ID comme une chaîne

            if ($stmt->execute()) {
                echo json_encode(["message" => "Données supprimées avec succès"]);
            } else {
                echo json_encode(["error" => "Erreur: " . $stmt->error]);
            }
            $stmt->close();
        }
        $checkStmt->close();
    } else {
        echo json_encode(["error" => "Aucune donnée à supprimer"]);
    }
}

// Fermer la connexion à la base de données
$conn->close();
?>
